package be.iminds.ilabt.jfed.espec.util;

import org.testng.annotations.Test;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.hamcrest.Matchers.is;

public class ChModPermissionsTest {
    @Test
    public void testIsOctal1() {
        assert(ChModPermissionsUtil.isOctalStyle("0644"));
        assert(ChModPermissionsUtil.isOctalStyle("0761"));
        assert(ChModPermissionsUtil.isOctalStyle("0010"));
        assert(ChModPermissionsUtil.isOctalStyle("010"));

        assert(!ChModPermissionsUtil.isSymbolicStyle("0644"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("0761"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("0010"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("010"));
    }
    @Test
    public void testIsOctal2() {
        assert(ChModPermissionsUtil.isOctalStyle("644"));
        assert(ChModPermissionsUtil.isOctalStyle("761"));
        assert(ChModPermissionsUtil.isOctalStyle("10"));

        assert(!ChModPermissionsUtil.isSymbolicStyle("644"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("761"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("10"));
    }
    @Test
    public void testIsSymbolic() {
        assert(ChModPermissionsUtil.isSymbolicStyle("uog=rwx"));
        assert(ChModPermissionsUtil.isSymbolicStyle("a=x"));
        for (String u : new String[] {"u", "o", "g", "a"}) {
            for (String p : new String[] {"r", "w", "x"}) {
                assert (ChModPermissionsUtil.isSymbolicStyle(u + "=" + p));
            }
        }
        assert(ChModPermissionsUtil.isSymbolicStyle("uo=rw"));
        assert(ChModPermissionsUtil.isSymbolicStyle("ou=wr"));
        assert(ChModPermissionsUtil.isSymbolicStyle("u=rw,og=r"));
        assert(ChModPermissionsUtil.isSymbolicStyle("u=r,o=w,g=x"));
        assert(ChModPermissionsUtil.isSymbolicStyle("u=rwx,og=r,g=w"));
        assert(ChModPermissionsUtil.isSymbolicStyle("u=rwx,og=r,g=w,g=w,a=w"));
        
        
        assert(!ChModPermissionsUtil.isOctalStyle("uog+rwx"));
        assert(!ChModPermissionsUtil.isOctalStyle("a+x"));
        assert(!ChModPermissionsUtil.isOctalStyle("uo+rw"));
        assert(!ChModPermissionsUtil.isOctalStyle("ou+wr"));
        assert(!ChModPermissionsUtil.isOctalStyle("u+rw,og+r"));
        assert(!ChModPermissionsUtil.isOctalStyle("u+r,o+w,g+x"));
        assert(!ChModPermissionsUtil.isOctalStyle("u+rwx,og+r,g+w"));
        assert(!ChModPermissionsUtil.isOctalStyle("u+rwx,og+r,g+w,g+w,a+w"));


        assert(!ChModPermissionsUtil.isSymbolicStyle("uog+rwx"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("a+x"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("uo+rw"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("ou+wr"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u+rw,og+r"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u+r,o+w,g+x"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u+rwx,og+r,g+w"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u+rwx,og+r,g+w,g+w,a+w"));


        assert(!ChModPermissionsUtil.isSymbolicStyle("uog-rwx"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("a-x"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("uo-rw"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("ou-wr"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u-rw,og-r"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u-r,o-w,g-x"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u-rwx,og-r,g-w"));
        assert(!ChModPermissionsUtil.isSymbolicStyle("u-rwx,og-r,g-w,g-w,a-w"));
    }

    @Test
    public void testToMask1() {
        assertThat(ChModPermissionsUtil.toMask("0644"), is(equalTo(0644)));
    }
    @Test
    public void testToMask2() {
        assertThat(ChModPermissionsUtil.toMask("644"), is(equalTo(0644)));
    }
    @Test
    public void testToMask2b() {
        assertThat(ChModPermissionsUtil.toMask("044"), is(equalTo(0044)));
    }
    @Test
    public void testToMask3() {
        assertThat(ChModPermissionsUtil.toMask("0421"), is(equalTo(0421)));
    }
    @Test
    public void testToMask3b() {
        assertThat(ChModPermissionsUtil.toMask("21"), is(equalTo(0021)));
    }
    @Test
    public void testToMask4() {
        assertThat(ChModPermissionsUtil.toMask("u=rw,og=r"), is(equalTo(0644)));
    }
    @Test
    public void testToMask5() {
        assertThat(ChModPermissionsUtil.toMask("uog=rwx"), is(equalTo(0777)));
    }
    @Test
    public void testToMask6() {
        assertThat(ChModPermissionsUtil.toMask("u=r"), is(equalTo(0400)));
        assertThat(ChModPermissionsUtil.toMask("u=w"), is(equalTo(0200)));
        assertThat(ChModPermissionsUtil.toMask("u=x"), is(equalTo(0100)));
    }
    @Test
    public void testToMask7() {
        assertThat(ChModPermissionsUtil.toMask("g=r"), is(equalTo(0040)));
        assertThat(ChModPermissionsUtil.toMask("g=w"), is(equalTo(0020)));
        assertThat(ChModPermissionsUtil.toMask("g=x"), is(equalTo(0010)));
    }
    @Test
    public void testToMask8() {
        assertThat(ChModPermissionsUtil.toMask("o=r"), is(equalTo(0004)));
        assertThat(ChModPermissionsUtil.toMask("o=w"), is(equalTo(0002)));
        assertThat(ChModPermissionsUtil.toMask("o=x"), is(equalTo(0001)));
    }
    @Test
    public void testToMask9() {
        assertThat(ChModPermissionsUtil.toMask("a=r"), is(equalTo(0444)));
        assertThat(ChModPermissionsUtil.toMask("a=w"), is(equalTo(0222)));
        assertThat(ChModPermissionsUtil.toMask("a=x"), is(equalTo(0111)));
    }
    @Test
    public void testToMask10() {
        assertThat(ChModPermissionsUtil.toMask("u=r,o=w,g=r"), is(equalTo(0442)));
    }
    @Test
    public void testToMask11() {
        assertThat(ChModPermissionsUtil.toMask("u=rwx,og=r,g=w"), is(equalTo(0764)));
    }
    @Test
    public void testToMask12() {
        assertThat(ChModPermissionsUtil.toMask("a=r,u=rwx,g=w"), is(equalTo(0764)));
    }
}